"use client";

import { useState } from "react";
import { useRouter, useSearchParams } from "next/navigation";
import { useAuth } from "@/lib/hooks/useAuth";
import { useStudents } from "@/lib/hooks/useStudents";
import { useClasses } from "@/lib/hooks/useClasses";
import DashboardLayout from "@/components/layout/DashboardLayout";
import { StudentList } from "@/components/students/StudentList";
import { StudentForm } from "@/components/students/StudentForm";
import { Button } from "@/components/ui/button";
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogHeader,
  DialogTitle,
} from "@/components/ui/dialog";
import { Student } from "@/lib/types";
import { UserPlus } from "lucide-react";

export default function StudentsPage() {
  const router = useRouter();
  const { user, loading: authLoading } = useAuth();
  const { students, loading: studentsLoading, refresh } = useStudents();
  const { classes, loading: classesLoading } = useClasses();
  
  const [selectedStudent, setSelectedStudent] = useState<Student | null>(null);
  const [isAddDialogOpen, setIsAddDialogOpen] = useState(false);
  const [isEditDialogOpen, setIsEditDialogOpen] = useState(false);
  const searchParams = useSearchParams();
  const classId = searchParams.get("classId") || undefined;

  // Handle viewing a student
  const handleViewStudent = (student: Student) => {
    setSelectedStudent(student);
    router.push(`/students/${student.id}`);
  };

  // Handle editing a student
  const handleEditStudent = (student: Student) => {
    setSelectedStudent(student);
    setIsEditDialogOpen(true);
  };

  // Check if user is authenticated and has appropriate role
  if (!authLoading && (!user || (user.role !== "admin" && user.role !== "teacher"))) {
    router.push("/auth");
    return null;
  }

  const isLoading = authLoading || studentsLoading || classesLoading;

  if (isLoading) {
    return (
      <DashboardLayout>
        <div className="flex items-center justify-center h-[calc(100vh-4rem)]">
          <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-primary"></div>
        </div>
      </DashboardLayout>
    );
  }

  return (
    <DashboardLayout>
      <div className="space-y-6">
        <div className="flex justify-between items-center">
          <div>
            <h1 className="text-3xl font-bold tracking-tight">{classId ? "Class Students" : "All Students"}</h1>
            <p className="text-muted-foreground">{classId ? "Manage student information and records in the class" :"Manage student information and records"}</p>
          </div>
          <Button onClick={() => setIsAddDialogOpen(true)}>
            <UserPlus className="h-4 w-4 mr-2" />
            Add Student
          </Button>
        </div>

        <StudentList onView={handleViewStudent} onEdit={handleEditStudent} classId={classId} />

        {/* Add Student Dialog */}
        <Dialog open={isAddDialogOpen} onOpenChange={setIsAddDialogOpen}>
          <DialogContent className="max-w-4xl">
            <DialogHeader>
              <DialogTitle>Add New Student</DialogTitle>
              <DialogDescription>
                Create a new student record in the system
              </DialogDescription>
            </DialogHeader>
            <StudentForm 
              classes={classes}
              onSuccess={() => {
                setIsAddDialogOpen(false);
                refresh();
              }}
            />
          </DialogContent>
        </Dialog>

        {/* Edit Student Dialog */}
        <Dialog open={isEditDialogOpen} onOpenChange={setIsEditDialogOpen}>
          <DialogContent className="max-w-4xl">
            <DialogHeader>
              <DialogTitle>Edit Student</DialogTitle>
              <DialogDescription>
                Update the student's information
              </DialogDescription>
            </DialogHeader>
            {selectedStudent && (
              <StudentForm 
                student={selectedStudent}
                classes={classes}
                onSuccess={() => { 
                  setIsEditDialogOpen(false);
                  refresh();
                }}
              />
            )}
          </DialogContent>
        </Dialog>
      </div>
    </DashboardLayout>
  );
}